Check Cruncher configuration This function checks if the Cruncher configuration is valid by verifying the presence of the jwsacruncher executable in the specified cruncher_bin_directory.
Source: R/ckeck_config.R
check_cruncher_configuration.RdCheck Cruncher configuration
This function checks if the Cruncher configuration is valid by verifying the presence of the jwsacruncher executable in the specified cruncher_bin_directory.
Usage
check_cruncher_configuration(
cruncher_bin_directory = getOption("cruncher_bin_directory"),
print_message = TRUE
)