multiprocessing_names: Get the names of the multiprocessings of a workspace
Description
Function to get the name of the multiprocessings that appears on 'JDemetra+' and the name of the corresponding XML file.
Usage
multiprocessing_names(workspace)
Value
A data.frame containing the name of the multiprocessings that appears on 'JDemetra+' (column name) and
the name of the associated XML files (column file).
Arguments
- workspace
Path to the workspace. By default a dialog box opens to choose the workspace.